@@ -11,7 +11,7 @@ DEFAULTS = {
     'LOG_REQUEST_BODY_LENGTH': 1000,
     'LOG_RESPONSE_BODY_LENGTH': 1000,
     'LOG_RESPONSE_BODY_CONTENT_TYPES': (
-        'application/json', 'application/xml', 'text/xml', 'text/csv', 'text/html', 'application/xhtml+xml'
+        'application/json', 'application/xml', 'text/xml', 'text/csv',
     ),
     'LOG_JSON_STRING_LENGTH': 250,
     'COMMAND_LOG_EXCLUDED_COMMANDS': (
@@ -51,6 +51,7 @@ DEFAULTS = {
     'PURGE_LOG_BACKUP_BATCH': 20000,
     'PURGE_LOG_DELETE_BATCH': 1000,
     'TASK_LOGGER_NAME': 'security.task',
+    'TASK_USE_ON_SUCCESS': False,
 }
 
 
