@@ -1,13 +1,10 @@
-import json
-
 from django.apps import apps
 from django.contrib.auth import get_user_model
 from django.core.exceptions import ObjectDoesNotExist
-from django.core.serializers.json import DjangoJSONEncoder
 from django.db.models import TextField
 from django.db.models.functions import Cast
 from django.template.defaultfilters import truncatechars
-from django.utils.html import format_html, format_html_join, mark_safe, format_html_join
+from django.utils.html import mark_safe
 from django.utils.translation import ugettext_lazy as _
 from django.contrib.contenttypes.models import ContentType
 
@@ -18,23 +15,17 @@ from is_core.generic_views.inlines.inline_table_views import InlineTableView
 from is_core.generic_views.mixins import TabItem, TabsViewMixin
 from is_core.generic_views.table_views import TableView
 from is_core.main import UIRESTModelISCore
-from is_core.utils import render_model_objects_with_link, render_model_object_with_link
-from is_core.utils.decorators import short_description
+from is_core.utils import render_model_objects_with_link, render_model_object_with_link, display_code
+from is_core.utils.decorators import short_description, relation
 
 from security.config import settings
-from security.models import CommandLog, InputLoggedRequest, OutputLoggedRequest, CeleryTaskLog, CeleryTaskRunLog
+from security.models import (
+    CommandLog, InputLoggedRequest, OutputLoggedRequest, CeleryTaskInvocationLog, CeleryTaskRunLog
+)
 
 from ansi2html import Ansi2HTMLConverter
 
 
-def display_json(value):
-    return json.dumps(value, indent=4, ensure_ascii=False, cls=DjangoJSONEncoder)
-
-
-def display_as_code(value):
-    return format_html('<code style="white-space:pre-wrap;">{}</code>', value) if value else value
-
-
 def display_related_objects(request, related_objects):
     related_object_instances = []
     for related_object in related_objects:
@@ -49,7 +40,8 @@ def display_related_objects(request, related_objects):
 def get_content_type_pks_of_parent_related_classes():
     return {
         ContentType.objects.get_for_model(model_class).pk
-        for model_class in (CommandLog, InputLoggedRequest, OutputLoggedRequest, CeleryTaskLog, CeleryTaskRunLog)
+        for model_class in (CommandLog, InputLoggedRequest, OutputLoggedRequest, CeleryTaskInvocationLog,
+                            CeleryTaskRunLog)
     }
 
 
@@ -103,10 +95,10 @@ class SecurityISCoreMixin:
         )
 
     @short_description(_('raised celery task logs'))
-    def display_celery_task_logs(self, obj, request):
+    def display_celery_task_invocation_logs(self, obj, request):
         return render_model_objects_with_link(
             request,
-            CeleryTaskLog.objects.filter(
+            CeleryTaskInvocationLog.objects.filter(
                 related_objects__object_id=obj.pk,
                 related_objects__object_ct_id=ContentType.objects.get_for_model(obj).pk
             )
@@ -119,29 +111,17 @@ class RequestsLogISCore(SecurityISCoreMixin, UIRESTModelISCore):
 
     can_create = can_update = can_delete = False
 
-    @short_description(_('queries'))
-    def queries_code(self, obj):
-        return display_as_code(display_json(obj.queries)) if obj else None
-
     @short_description(_('request body'))
     def request_body_code(self, obj):
-        return display_as_code(obj.request_body) if obj else None
-
-    @short_description(_('request headers'))
-    def request_headers_code(self, obj):
-        return display_as_code(display_json(obj.request_headers)) if obj else None
+        return display_code(obj.request_body) if obj else None
 
     @short_description(_('response body'))
     def response_body_code(self, obj):
-        return display_as_code(obj.response_body) if obj else None
-
-    @short_description(_('response headers'))
-    def response_headers_code(self, obj):
-        return display_as_code(display_json(obj.response_headers)) if obj else None
+        return display_code(obj.response_body) if obj else None
 
     @short_description(_('error description'))
     def error_description_code(self, obj):
-        return display_as_code(obj.error_description) if obj else None
+        return display_code(obj.error_description) if obj else None
 
 
 class InputRequestsLogISCore(RequestsLogISCore):
@@ -157,13 +137,13 @@ class InputRequestsLogISCore(RequestsLogISCore):
 
     form_fieldsets = (
         (_('Request'), {'fields': ('created_at', 'changed_at', 'request_timestamp', 'host', 'method', 'path',
-                                   'queries_code', 'request_headers_code', 'request_body_code', 'is_secure')}),
-        (_('Response'), {'fields': ('response_timestamp', 'response_code', 'status', 'response_headers_code',
+                                   'queries', 'request_headers', 'request_body_code', 'is_secure')}),
+        (_('Response'), {'fields': ('response_timestamp', 'response_code', 'status', 'response_headers',
                                     'response_body_code', 'type', 'error_description_code')}),
         (_('User information'), {'fields': ('user', 'ip')}),
         (_('Extra information'), {'fields': ('slug', 'response_time', 'display_related_objects',
                                              'display_output_logged_requests', 'display_command_logs',
-                                             'display_celery_task_logs')}),
+                                             'display_celery_task_invocation_logs')}),
     )
 
     def get_form_fieldsets(self, request, obj=None):
@@ -199,8 +179,8 @@ class OutputRequestsLogISCore(RequestsLogISCore):
 
     form_fieldsets = (
         (_('Request'), {'fields': ('created_at', 'changed_at', 'request_timestamp', 'host', 'method', 'path',
-                                   'queries_code', 'request_headers_code', 'request_body_code', 'is_secure')}),
-        (_('Response'), {'fields': ('response_timestamp', 'response_code', 'status', 'response_headers_code',
+                                   'queries', 'request_headers', 'request_body_code', 'is_secure')}),
+        (_('Response'), {'fields': ('response_timestamp', 'response_code', 'status', 'response_headers',
                                     'response_body_code', 'error_description_code')}),
         (_('Extra information'), {'fields': ('slug', 'response_time', 'display_related_objects', 'display_source')}),
     )
@@ -217,16 +197,21 @@ class CommandLogISCore(SecurityISCoreMixin, UIRESTModelISCore):
     )
 
     form_fieldsets = (
-        (None, {
-            'fields': ('created_at', 'changed_at', 'name', 'input', 'output_html', 'error_message',
-                       'display_related_objects', 'display_source', 'display_output_logged_requests',
-                       'display_command_logs', 'display_celery_task_logs'),
-            'class': 'col-sm-6'
-        }),
-        (None, {
-            'fields': ('start', 'stop', 'time', 'executed_from_command_line', 'is_successful'),
-            'class': 'col-sm-6'
-        }),
+        (None, {'fieldsets': (
+            (None, {
+                'fields': (
+                    'created_at', 'changed_at', 'name', 'input', 'error_message', 'display_related_objects',
+                    'display_source', 'display_output_logged_requests', 'display_command_logs',
+                    'display_celery_task_invocation_logs'
+                ),
+                'class': 'col-sm-6'
+            }),
+            (None, {
+                'fields': ('start', 'stop', 'time', 'executed_from_command_line', 'is_successful'),
+                'class': 'col-sm-6'
+            })
+        ),}),
+        (None, {'fields': ('output_html',)})
     )
 
     abstract = True
@@ -234,69 +219,27 @@ class CommandLogISCore(SecurityISCoreMixin, UIRESTModelISCore):
     @short_description(_('output'))
     def output_html(self, obj=None):
         if obj and obj.output is not None:
-            conv = Ansi2HTMLConverter()
-            output = mark_safe(conv.convert(obj.output, full=False))
-            return display_as_code(output)
+            return display_code(mark_safe(Ansi2HTMLConverter().convert(obj.output, full=False)))
         return None
 
 
-class CeleryTaskLogTabs(TabsViewMixin):
+class CeleryTaskInvocationLogTabs(TabsViewMixin):
 
     tabs = (
-        TabItem('list-celerytasklog', _('celery task')),
+        TabItem('list-celerytaskinvocationlog', _('celery task')),
         TabItem('list-celerytaskrunlog', _('celery task run')),
     )
 
 
-class CeleryTaskLogTableView(CeleryTaskLogTabs, TableView):
+class CeleryTaskInvocationLogTableView(CeleryTaskInvocationLogTabs, TableView):
     pass
 
 
-class CeleryTaskRunLogISCore(SecurityISCoreMixin, UIRESTModelISCore):
+class CeleryTaskInvocationTableView(InlineTableView):
 
-    model = CeleryTaskRunLog
-
-    abstract = True
-
-    can_create = can_update = can_delete = False
-
-    rest_extra_filter_fields = (
-        'celery_task_id',
-    )
-
-    ui_list_fields = (
-        'celery_task_id', 'created_at', 'changed_at', 'name', 'state', 'start', 'stop', 'time', 'result', 'retries',
-        'get_task_log'
-    )
-
-    form_fields = (
-        'celery_task_id', 'task_log', 'start', 'stop', 'time', 'state', 'result', 'error_message', 'output_html',
-        'retries', 'estimated_time_of_next_retry', 'display_related_objects', 'display_output_logged_requests',
-        'display_command_logs', 'display_celery_task_logs'
-    )
-
-    ui_list_view = CeleryTaskLogTableView
-
-    default_ordering = ('-created_at',)
-
-    @short_description(_('celery task log'))
-    def task_log(self, obj):
-        return obj.get_task_log()
-
-    @short_description(_('output'))
-    def output_html(self, obj):
-        if obj and obj.output is not None:
-            conv = Ansi2HTMLConverter()
-            output = mark_safe(conv.convert(obj.output, full=False))
-            return display_as_code(output)
-        return None
-
-
-class CeleryTaskRunLogInlineTableView(InlineTableView):
-
-    model = CeleryTaskRunLog
+    model = CeleryTaskInvocationLog
     fields = (
-        'created_at', 'changed_at', 'start', 'stop', 'time', 'state', 'result', 'retries'
+        'id', 'invocation_id', 'celery_task_id', 'created_at', 'changed_at'
     )
 
     def _get_list_filter(self):
@@ -307,31 +250,89 @@ class CeleryTaskRunLogInlineTableView(InlineTableView):
         }
 
 
-class CeleryTaskLogISCore(SecurityISCoreMixin, UIRESTModelISCore):
+class CeleryTaskRunLogISCore(SecurityISCoreMixin, UIRESTModelISCore):
 
-    model = CeleryTaskLog
+    model = CeleryTaskRunLog
 
     abstract = True
 
     can_create = can_update = can_delete = False
+    show_in_menu = False
+
+    rest_extra_filter_fields = (
+        'celery_task_id',
+    )
 
     ui_list_fields = (
-        'celery_task_id', 'created_at', 'changed_at', 'name', 'short_input', 'state', 'get_start', 'get_stop',
+        'id', 'celery_task_id', 'created_at', 'changed_at', 'name', 'state', 'start', 'stop', 'time', 'retries',
         'queue_name'
     )
 
     form_fieldsets = (
         (None, {
             'fields': (
-                'celery_task_id', 'created_at', 'changed_at', 'name', 'state', 'get_start', 'get_stop',
-                'estimated_time_of_first_arrival', 'expires', 'stale', 'queue_name', 'input', 'display_related_objects',
-                'display_source'
+                'celery_task_id', 'start', 'stop', 'time', 'state', 'result', 'error_message', 'output_html',
+                'retries', 'estimated_time_of_next_retry', 'queue_name', 'display_related_objects',
+                'display_output_logged_requests',  'display_command_logs', 'display_celery_task_invocation_logs'
+            )
+        }),
+        (_('celery task invocations'), {'inline_view': CeleryTaskInvocationTableView}),
+    )
+
+    ui_list_view = CeleryTaskInvocationLogTableView
+
+    default_ordering = ('-created_at',)
+
+    @short_description(_('output'))
+    def output_html(self, obj):
+        if obj and obj.output is not None:
+            conv = Ansi2HTMLConverter()
+            output = mark_safe(conv.convert(obj.output, full=False))
+            return display_code(output)
+        return None
+
+
+class CeleryTaskRunLogInlineTableView(InlineTableView):
+
+    model = CeleryTaskRunLog
+    fields = (
+        'created_at', 'changed_at', 'start', 'stop', 'time', 'state', 'retries'
+    )
+
+    def _get_list_filter(self):
+        return {
+            'filter': {
+                'celery_task_id': self.parent_instance.celery_task_id
+            }
+        }
+
+
+class CeleryTaskInvocationLogISCore(SecurityISCoreMixin, UIRESTModelISCore):
+
+    model = CeleryTaskInvocationLog
+
+    abstract = True
+
+    can_create = can_update = can_delete = False
+
+    ui_list_fields = (
+        'id', 'invocation_id', 'celery_task_id', 'created_at', 'changed_at', 'name', 'short_input', 'state', 'get_start',
+        'get_stop', 'queue_name'
+    )
+
+    form_fieldsets = (
+        (None, {
+            'fields': (
+                'invocation_id', 'celery_task_id', 'created_at', 'changed_at', 'name', 'state', 'get_start', 'get_stop',
+                'estimated_time_of_first_arrival', 'expires_at', 'stale_at', 'queue_name', 'input',
+                'display_source', 'applied_at', 'triggered_at', 'is_unique', 'is_async', 'is_duplicate', 'is_on_commit',
+                'display_related_objects',
             )
         }),
         (_('celery task runs'), {'inline_view': CeleryTaskRunLogInlineTableView}),
     )
 
-    ui_list_view = CeleryTaskLogTableView
+    ui_list_view = CeleryTaskInvocationLogTableView
 
     @filter_by('input')
     @order_by('input')
