@@ -3,6 +3,7 @@ import logging
 import re
 import sys
 import traceback
+from time import time
 from contextlib import ContextDecorator
 from importlib import import_module
 from io import StringIO
@@ -10,11 +11,14 @@ from threading import local
 
 from django.conf import settings as django_settings
 from django.core.exceptions import ImproperlyConfigured
+from django.core.management.base import OutputWrapper
 from django.core.signals import request_finished
 from django.db.transaction import get_connection
 from django.urls import resolve
 from django.urls.exceptions import Resolver404
 from django.utils.timezone import now
+from django.db.models import F, Value as V
+from django.db.models.functions import Concat
 
 from .config import settings
 
@@ -312,32 +316,54 @@ def remove_nul_from_string(value):
     return value.replace('\x00', '')
 
 
+def is_atty_string(s):
+    return bool(re.search('^\\x1b\[\d+m$', s))
+
+
 class LogStringIO(StringIO):
 
-    def __init__(self, post_write_callback=None, *args, **kwargs):
+    BOLD = '\x1b[1m'
+    RESET = '\x1b[0m'
+
+    def __init__(self, flush_callback=None, flush_timeout=5, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self._last_newline = 0
-        self._post_write_callback = post_write_callback
+        self._flush_callback = flush_callback
+        self._write_time = True
+        self._last_flush_time = time()
+        self._flush_timeout = flush_timeout
 
-    def _post_write(self):
-        if self._post_write_callback:
-            self._post_write_callback(self)
+    def _flush(self):
+        if self._flush_callback and time() - self._last_flush_time > self._flush_timeout:
+            self._flush_callback(self)
+            self._last_flush_time = time()
 
     def write(self, s):
-        line_first = True
-        for line in s.split('\n'):
-            if not line_first:
-                super().write('\n')
-                self._last_newline = self.tell()
+        lines = s.split('\n')
+
+        for i, line in enumerate(lines):
             cursor_first = True
             for cursor_block in line.split('\r'):
                 if not cursor_first:
                     self.seek(self._last_newline)
                     self.truncate()
+                    self._write_time = True
                 cursor_first = False
+
+                if self._write_time and not is_atty_string(cursor_block):
+                    cursor_block = '{}{}[{}]{} {}'.format(
+                        self.RESET, self.BOLD, now().strftime('%d-%m-%Y %H:%M:%S'), self.RESET, cursor_block
+                    )
+                    self._write_time = False
+
                 super().write(cursor_block)
-            line_first = False
-        self._post_write()
+
+            if i != len(lines) - 1:
+                super().write('\n')
+                self._last_newline = self.tell()
+                self._write_time = True
+
+        self._flush()
 
     def isatty(self):
         return True
@@ -423,7 +449,7 @@ class CommandLogger(StringIO):
             for related_object in related_objects:
                 self.command_log.related_objects.add(related_object)
 
-        self.output = LogStringIO(post_write_callback=self._store_log_output)
+        self.output = LogStringIO(flush_callback=self._store_log_output)
         stdout = TeeStringIO(self.stdout, self.output)
         stderr = TeeStringIO(self.stderr, self.output)
 
